@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2017, Met Office
+# (C) British Crown Copyright 2010 - 2018, Met Office
 #
 # This file is part of Iris.
 #
@@ -37,7 +37,24 @@ import iris.coords
 import iris.coord_systems
 import iris.exceptions
 from iris.util import _meshgrid
+from ._grid_angles import gridcell_angles, rotate_grid_vectors
 
+# List of contents to control Sphinx autodocs.
+# Unfortunately essential to get docs for the grid_angles functions.
+__all__ = [
+    'area_weights',
+    'cosine_latitude_weights',
+    'get_xy_contiguous_bounded_grids',
+    'get_xy_grids',
+    'gridcell_angles',
+    'project',
+    'rotate_grid_vectors',
+    'rotate_pole',
+    'rotate_winds',
+    'unrotate_pole',
+    'wrap_lons',
+    'DistanceDifferential',
+    'PartialDifferential']
 
 # This value is used as a fall-back if the cube does not define the earth
 DEFAULT_SPHERICAL_EARTH_RADIUS = 6367470
@@ -332,7 +349,7 @@ def _quadrant_area(radian_lat_bounds, radian_lon_bounds, radius_of_earth):
 
 
 def area_weights(cube, normalize=False):
-    """
+    r"""
     Returns an array of area weights, with the same dimensions as the cube.
 
     This is a 2D lat/lon area weights array, repeated over the non lat/lon
@@ -440,7 +457,7 @@ def area_weights(cube, normalize=False):
 
 
 def cosine_latitude_weights(cube):
-    """
+    r"""
     Returns an array of latitude weights, with the same dimensions as
     the cube. The weights are the cosine of latitude.
 
@@ -950,7 +967,7 @@ def _transform_distance_vectors_tolerance_mask(src_crs, x, y, tgt_crs,
 
 
 def rotate_winds(u_cube, v_cube, target_cs):
-    """
+    r"""
     Transform wind vectors to a different coordinate system.
 
     The input cubes contain U and V components parallel to the local X and Y
