@@ -132,9 +132,6 @@ class Grid(object):
     An abstract class representing the default/file-level grid
     definition for a FieldsFile.
 
-    .. deprecated:: 1.10
-        The module :mod:`iris.fileformats.ff` is deprecated.
-
     """
     def __init__(self, column_dependent_constants, row_dependent_constants,
                  real_constants, horiz_grid_type):
@@ -155,8 +152,6 @@ class Grid(object):
         * horiz_grid_type (integer):
             `horiz_grid_type` from a FFHeader.
 
-        .. deprecated:: 1.10
-
         """
         self.column_dependent_constants = column_dependent_constants
         self.row_dependent_constants = row_dependent_constants
@@ -213,9 +208,6 @@ class ArakawaC(Grid):
     """
     An abstract class representing an Arakawa C-grid.
 
-    .. deprecated:: 1.10
-        The module :mod:`iris.fileformats.ff` is deprecated.
-
     """
     def _x_vectors(self):
         x_p, x_u = None, None
@@ -276,9 +268,6 @@ class NewDynamics(ArakawaC):
 
     The theta and u points are at the poles.
 
-    .. deprecated:: 1.10
-        The module :mod:`iris.fileformats.ff` is deprecated.
-
     """
 
     _v_offset = 0.5
@@ -298,9 +287,6 @@ class ENDGame(ArakawaC):
 
     The v points are at the poles.
 
-    .. deprecated:: 1.10
-        The module :mod:`iris.fileformats.ff` is deprecated.
-
     """
 
     _v_offset = -0.5
@@ -318,9 +304,6 @@ class FFHeader(object):
     """
     A class to represent the FIXED_LENGTH_HEADER section of a FieldsFile.
 
-    .. deprecated:: 1.10
-        The module :mod:`iris.fileformats.ff` is deprecated.
-
     """
 
     GRID_STAGGERING_CLASS = {3: NewDynamics, 6: ENDGame}
@@ -339,8 +322,6 @@ class FFHeader(object):
         Returns:
             FFHeader object.
 
-        .. deprecated:: 1.10
-
         """
 
         #: File name of the FieldsFile.
@@ -454,9 +435,6 @@ class FF2PP(object):
     """
     A class to extract the individual PPFields from within a FieldsFile.
 
-    .. deprecated:: 1.10
-        The module :mod:`iris.fileformats.ff` is deprecated.
-
     """
 
     def __init__(self, filename, read_data=False,
@@ -484,11 +462,6 @@ class FF2PP(object):
             >>> for field in ff.FF2PP(filename):
             ...     print(field)
 
-        .. deprecated:: 1.10
-            The module :mod:`iris.fileformats.ff` is deprecated.
-            Please use :func:`iris.fileformats.um.um_to_pp` in place of
-            :class:`iris.fileformats.ff.FF2PP`.
-
         """
 
         self._ff_header = FFHeader(filename, word_depth=word_depth)
@@ -782,13 +755,13 @@ class FF2PP(object):
                             # Read the actual bytes. This can then be converted
                             # to a numpy array at a higher level.
                             ff_file_seek(data_offset, os.SEEK_SET)
-                            result_field._data = pp.LoadedArrayBytes(
+                            result_field.data = pp.LoadedArrayBytes(
                                 ff_file.read(data_depth), data_type)
                         else:
                             # Provide enough context to read the data bytes
                             # later.
-                            result_field._data = (self._filename, data_offset,
-                                                  data_depth, data_type)
+                            result_field.data = (self._filename, data_offset,
+                                                 data_depth, data_type)
 
                         data_offset += data_depth
 
@@ -821,11 +794,6 @@ def load_cubes(filenames, callback, constraints=None):
         file (order is not preserved when there is a field with
         orography references).
 
-    .. deprecated:: 1.10
-            The module :mod:`iris.fileformats.ff` is deprecated.
-            Please use :func:`iris.fileformats.um.load_cubes` in place of
-            :func:`iris.fileformats.ff.load_cubes`.
-
     """
     return pp._load_cubes_variable_loader(filenames, callback, FF2PP,
                                           constraints=constraints)
@@ -839,11 +807,6 @@ def load_cubes_32bit_ieee(filenames, callback, constraints=None):
 
         :func:`load_cubes` for keyword details
 
-    .. deprecated:: 1.10
-            The module :mod:`iris.fileformats.ff` is deprecated.
-            Please use :func:`iris.fileformats.um.load_cubes_32bit_ieee`
-            in place of :func:`iris.fileformats.ff.load_cubes_32bit_ieee`.
-
     """
     return pp._load_cubes_variable_loader(filenames, callback, FF2PP,
                                           {'word_depth': 4},
