@@ -245,6 +245,11 @@ class STASH(collections.namedtuple('STASH', 'model section item')):
         >>> print(iris.fileformats.pp.STASH(1, 16, 203))
         m01s16i203
 
+    A stash object can be compared directly
+    to its string representation:
+    >>> iris.fileformats.pp.STASH(1, 0, 4) == 'm01s0i004'
+    True
+
     """
 
     __slots__ = ()
@@ -826,7 +831,7 @@ def _pp_attribute_names(header_defn):
     special_headers = list('_' + name for name in _SPECIAL_HEADERS)
     extra_data = list(EXTRA_DATA.values())
     special_attributes = ['_raw_header', 'raw_lbtim', 'raw_lbpack',
-                          'boundary_packing']
+                          'boundary_packing', '_index_in_structured_load_file']
     return normal_headers + special_headers + extra_data + special_attributes
 
 
@@ -859,6 +864,7 @@ class PPField(six.with_metaclass(abc.ABCMeta, object)):
         self.raw_lbtim = None
         self.raw_lbpack = None
         self.boundary_packing = None
+        self._index_in_structured_load_file = None
         if header is not None:
             self.raw_lbtim = header[self.HEADER_DICT['lbtim'][0]]
             self.raw_lbpack = header[self.HEADER_DICT['lbpack'][0]]
@@ -1881,7 +1887,7 @@ def load_pairs_from_fields(pp_fields):
         An iterable of :class:`iris.fileformats.pp.PPField`.
 
     Returns:
-        An iterable of :class:`iris.cube.Cube`s.
+        An iterable of :class:`iris.cube.Cube`\ s.
 
     This capability can be used to filter out fields before they are passed to
     the load pipeline, and amend the cubes once they are created, using
