@@ -642,7 +642,7 @@ class IrisTest_nometa(unittest.TestCase):
         self._assertMaskedArray(np.testing.assert_array_almost_equal, a, b,
                                 strict, decimal=decimal)
 
-    def assertArrayAllClose(self, a, b, rtol=1.0e-7, atol=0.0, **kwargs):
+    def assertArrayAllClose(self, a, b, rtol=1.0e-7, atol=1.0e-8, **kwargs):
         """
         Check arrays are equal, within given relative + absolute tolerances.
 
@@ -660,10 +660,35 @@ class IrisTest_nometa(unittest.TestCase):
 
         Performs pointwise toleranced comparison, and raises an assertion if
         the two are not equal 'near enough'.
-        For full details see underlying routine numpy.testing.assert_allclose.
+        For full details see underlying routine numpy.allclose.
 
         """
-        np.testing.assert_allclose(a, b, rtol=rtol, atol=atol, **kwargs)
+        # Handle the 'err_msg' kwarg, which is the only API difference
+        # between np.allclose and np.testing_assert_allclose.
+        msg = kwargs.pop('err_msg', None)
+        ok = np.allclose(a, b, rtol=rtol, atol=atol, **kwargs)
+        if not ok:
+            # Calculate errors above a pointwise tolerance : The method is
+            # taken from "numpy.core.numeric.isclose".
+            a, b = np.broadcast_arrays(a, b)
+            errors = (np.abs(a-b) - atol + rtol * np.abs(b))
+            worst_inds = np.unravel_index(np.argmax(errors.flat), errors.shape)
+
+            if msg is None:
+                # Build a more useful message than np.testing.assert_allclose.
+                msg = (
+                    '\nARRAY CHECK FAILED "assertArrayAllClose" :'
+                    '\n  with shapes={} {}, atol={}, rtol={}'
+                    '\n  worst at element {} :  a={}  b={}'
+                    '\n  absolute error ~{:.3g}, equivalent to rtol ~{:.3e}')
+                aval, bval = a[worst_inds], b[worst_inds]
+                absdiff = np.abs(aval - bval)
+                equiv_rtol = absdiff / bval
+                msg = msg.format(
+                   a.shape, b.shape, atol, rtol, worst_inds, aval, bval,
+                   absdiff, equiv_rtol)
+
+            raise AssertionError(msg)
 
     @contextlib.contextmanager
     def temp_filename(self, suffix=''):
