@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2016, Met Office
+# (C) British Crown Copyright 2010 - 2017, Met Office
 #
 # This file is part of Iris.
 #
@@ -18,13 +18,11 @@
 Integration tests for grib2 file loading.
 
 This code used to be part of 'tests/test_grib_load.py', but these integration-
-style tests have been split out of there :  They now work with either the
-internal 'iris.fileformats.grib' module *or* the newer, external
-'iris_grib' package.
+style tests have been split out of there.
 
 The remainder of the old 'tests/test_grib_load.py' is now renamed as
 'tests/test_grib_load_translations.py'.  Those tests are implementation-
-specific, and target the deprecated internal module 'iris.fileformats.grib'.
+specific, and target the module 'iris_grib'.
 
 """
 from __future__ import (absolute_import, division, print_function)
@@ -36,26 +34,16 @@ import iris.tests as tests
 
 import iris
 import iris.exceptions
-from iris.tests import mock
 import iris.tests.stock
 import iris.util
 from unittest import skipIf
 
-
-if tests.GRIB_AVAILABLE:
-    try:
-        import iris_grib
-        iris_internal_grib_module = None
-    except ImportError:
-        from iris.fileformats import grib as iris_internal_grib_module
-else:
-    iris_internal_grib_module = None
-
-# Skip out some tests that currently fail with 'iris_grib'.
+# Skip out some tests that fail now that grib edition 2 files no longer use
+# the GribWrapper.
 # TODO: either fix these problems, or remove the tests.
-skip_irisgrib_fails = skipIf(iris_internal_grib_module is None,
-                             'Test(s) are not currently ussable with '
-                             '"iris_grib".')
+skip_irisgrib_fails = skipIf(True,
+                             'Test(s) are not currently usable with the new '
+                             'grib 2 loader.')
 
 
 @tests.skip_data
@@ -83,7 +71,6 @@ class TestBasicLoad(tests.GraphicsTest):
         self.assertCML(cubes, ("grib_load", "3_layer.cml"))
 
     def test_load_masked(self):
-
         gribfile = tests.get_data_path(
             ('GRIB', 'missing_values', 'missing_values.grib2'))
         cubes = iris.load(gribfile)
@@ -149,12 +136,6 @@ class TestBasicLoad(tests.GraphicsTest):
             ("GRIB", "reduced", "reduced_gg.grib2")))
         self.assertCML(cube, ("grib_load", "reduced_gg_grib2.cml"))
 
-    @skip_irisgrib_fails
-    def test_reduced_missing(self):
-        cube = iris.load_cube(tests.get_data_path(
-            ("GRIB", "reduced", "reduced_ll_missing.grib1")))
-        self.assertCML(cube, ("grib_load", "reduced_ll_missing_grib1.cml"))
-
 
 @tests.skip_data
 @tests.skip_grib
@@ -201,7 +182,6 @@ class TestShapeOfEarth(tests.GraphicsTest):
         cube = self._old_compat_load("1.grib2")
         self.assertCML(cube, ("grib_load", "earth_shape_1.cml"))
 
-    @skip_irisgrib_fails
     def test_shape_of_earth_IAU65(self):
         # IAU65 oblate sphere
         cube = self._old_compat_load("2.grib2")
@@ -212,13 +192,11 @@ class TestShapeOfEarth(tests.GraphicsTest):
         cube = self._old_compat_load("3.grib2")
         self.assertCML(cube, ("grib_load", "earth_shape_3.cml"))
 
-    @skip_irisgrib_fails
     def test_shape_of_earth_IAG_GRS80(self):
         # IAG-GRS80 oblate spheroid
         cube = self._old_compat_load("4.grib2")
         self.assertCML(cube, ("grib_load", "earth_shape_4.cml"))
 
-    @skip_irisgrib_fails
     def test_shape_of_earth_WGS84(self):
         # WGS84
         cube = self._old_compat_load("5.grib2")
