@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2016, Met Office
+# (C) British Crown Copyright 2010 - 2018, Met Office
 #
 # This file is part of Iris.
 #
@@ -33,7 +33,6 @@ import shutil
 import stat
 import tempfile
 
-import biggus
 import netCDF4 as nc
 import numpy as np
 import numpy.ma as ma
@@ -47,6 +46,7 @@ import iris.util
 import iris.coord_systems as icoord_systems
 from iris.tests import mock
 import iris.tests.stock as stock
+from iris._lazy_data import is_lazy_data
 
 
 @tests.skip_data
@@ -111,7 +111,7 @@ class TestNetCDFLoad(tests.IrisTest):
         cube = iris.load_cube(tests.get_data_path(
             ('NetCDF', 'rotated', 'xy', 'rotPole_landAreaFraction.nc')))
         # Make sure the AuxCoords have lazy data.
-        self.assertIsInstance(cube.coord('latitude')._points, biggus.Array)
+        self.assertTrue(is_lazy_data(cube.coord('latitude').core_points()))
         self.assertCML(cube, ('netcdf', 'netcdf_rotated_xy_land.cml'))
 
     def test_load_rotated_xyt_precipitation(self):
@@ -564,9 +564,10 @@ class TestNetCDFSave(tests.IrisTest):
         # Test saving a CF-netCDF file which contains a hybrid height
         # (i.e. dimensionless vertical) coordinate.
         # Read PP input file.
+        names = ['air_potential_temperature', 'surface_altitude']
         file_in = tests.get_data_path(
             ('PP', 'COLPEX', 'small_colpex_theta_p_alt.pp'))
-        cube = iris.load_cube(file_in, 'air_potential_temperature')
+        cube = iris.load_cube(file_in, names[0])
 
         # Write Cube to netCDF file.
         with self.temp_filename(suffix='.nc') as file_out:
@@ -577,10 +578,12 @@ class TestNetCDFSave(tests.IrisTest):
                            ('netcdf', 'netcdf_save_hybrid_height.cdl'))
 
             # Read netCDF file.
-            cube = iris.load_cube(file_out)
+            cubes = iris.load(file_out)
+            cubes_names = [c.name() for c in cubes]
+            self.assertEqual(cubes_names, names)
 
             # Check the PP read, netCDF write, netCDF read mechanism.
-            self.assertCML(cube,
+            self.assertCML(cubes.extract(names[0])[0],
                            ('netcdf', 'netcdf_save_load_hybrid_height.cml'))
 
     @tests.skip_data
@@ -711,6 +714,7 @@ class TestNetCDFSave(tests.IrisTest):
                  'flag_masks': 'a',
                  'flag_meanings': 'b',
                  'flag_values': 'c',
+                 'missing_value': 1.e20,
                  'STASH': iris.fileformats.pp.STASH(1, 2, 3)}
         for k, v in six.iteritems(avars):
             self.cube.attributes[k] = v
