@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2017, Met Office
+# (C) British Crown Copyright 2017 - 2018, Met Office
 #
 # This file is part of Iris.
 #
@@ -27,13 +27,13 @@ from six.moves import (filter, input, map, range, zip)  # noqa
 import iris.tests as tests
 
 import copy
-import mock
 import numpy as np
 import numpy.ma as ma
 import six
 
 from iris._data_manager import DataManager
 from iris._lazy_data import as_lazy_data
+from iris.tests import mock
 
 
 class Test___copy__(tests.IrisTest):
