@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2013 - 2017, Met Office
+# (C) British Crown Copyright 2013 - 2018, Met Office
 #
 # This file is part of Iris.
 #
@@ -34,7 +34,8 @@ import iris
 from iris._lazy_data import as_lazy_data
 from iris.coord_systems import (GeogCS, TransverseMercator, RotatedGeogCS,
                                 LambertConformal, Mercator, Stereographic,
-                                LambertAzimuthalEqualArea)
+                                LambertAzimuthalEqualArea,
+                                AlbersEqualArea)
 from iris.coords import DimCoord
 from iris.cube import Cube
 from iris.fileformats.netcdf import Saver
@@ -472,6 +473,33 @@ class Test_write_fill_value(tests.IrisTest):
                 pass
 
 
+class Test_cf_valid_var_name(tests.IrisTest):
+    def test_no_replacement(self):
+        self.assertEqual(Saver.cf_valid_var_name('valid_Nam3'),
+                         'valid_Nam3')
+
+    def test_special_chars(self):
+        self.assertEqual(Saver.cf_valid_var_name('inv?alid'),
+                         'inv_alid')
+
+    def test_leading_underscore(self):
+        self.assertEqual(Saver.cf_valid_var_name('_invalid'),
+                         'var__invalid')
+
+    def test_leading_number(self):
+        self.assertEqual(Saver.cf_valid_var_name('2invalid'),
+                         'var_2invalid')
+
+    def test_leading_invalid(self):
+        self.assertEqual(Saver.cf_valid_var_name('?invalid'),
+                         'var__invalid')
+
+    def test_no_hyphen(self):
+        # CF explicitly prohibits hyphen, even though it is fine in NetCDF.
+        self.assertEqual(Saver.cf_valid_var_name('valid-netcdf'),
+                         'valid_netcdf')
+
+
 class _Common__check_attribute_compliance(object):
     def setUp(self):
         self.container = mock.Mock(name='container', attributes={})
@@ -758,6 +786,26 @@ class Test__create_cf_grid_mapping(tests.IrisTest):
                     }
         self._test(coord_system, expected)
 
+    def test_aea_cs(self):
+        coord_system = AlbersEqualArea(
+            latitude_of_projection_origin=52,
+            longitude_of_central_meridian=10,
+            false_easting=100,
+            false_northing=200,
+            standard_parallels=(38, 50),
+            ellipsoid=GeogCS(6377563.396, 6356256.909))
+        expected = {'grid_mapping_name': b'albers_conical_equal_area',
+                    'latitude_of_projection_origin': 52,
+                    'longitude_of_central_meridian': 10,
+                    'false_easting': 100,
+                    'false_northing': 200,
+                    'standard_parallel': (38, 50),
+                    'semi_major_axis': 6377563.396,
+                    'semi_minor_axis': 6356256.909,
+                    'longitude_of_prime_meridian': 0,
+                    }
+        self._test(coord_system, expected)
+
 
 class Test__create_cf_cell_measure_variable(tests.IrisTest):
     # Saving of masked data is disallowed.
